@@ -5,10 +5,15 @@
 
 use crate::Doc;
 
-pub mod rust_markdown_tag;
-pub mod rust_remove_comments;
+mod intralinks;
+mod rust_markdown_tag;
+mod rust_remove_comments;
 mod utils;
 
+pub use intralinks::{DocTransformIntralinks, IntralinkError};
+pub use rust_markdown_tag::DocTransformRustMarkdownTag;
+pub use rust_remove_comments::DocTransformRustRemoveComments;
+
 pub trait DocTransform {
     type E;
 
